# nio Framework (Python)

[![PyPI version](https://badge.fury.io/py/nio.svg)](https://badge.fury.io/py/nio)

A Python framework for developing nio blocks and modules.

## Installation

The easiest way to install the nio framework is via PyPI.

```
pip install nio
```
